@@ -1,9 +1,7 @@
 # -*- coding: utf-8 -*-
 
-from enum import Enum
 
-
-class STATUS(Enum):
+class STATUS:
     START = 0
     PAUSE = 1
     RESUME = 2
@@ -11,7 +9,7 @@ class STATUS(Enum):
 
 
 class AudioControl:
-    def __init__(self, audio_url, text, status: STATUS):
+    def __init__(self, audio_url: str, text: str, status: STATUS):
         self.audio_url = audio_url
         self.text = text
         self.status = status
@@ -19,9 +17,9 @@ class AudioControl:
 
 class AudioAction:
     def __init__(self, data=None):
-        self.guild_id = ""
-        self.channel_id = ""
-        self.audio_url = ""
-        self.text = ""
+        self.guild_id: str = ""
+        self.channel_id: str = ""
+        self.audio_url: str = ""
+        self.text: str = ""
         if data is not None:
             self.__dict__ = data
